Admin Tasks
-----------

This section describes how to perform administration tasks for the Device plugin.

Enrolling Devices
`````````````````

The enrolled devices are displayed to the administrator via the admin UI.
To remove, enroll or unenroll devices, follow this procedure:

----

#.  Open the Peek Admin UI and navigate to the Device plugin.

#.  Click on the **Device** tab

#.  Toggle the **Enrollment** button.

#.  Click save.

.. image:: admin_task_devices.png

----

The user will see their device toggle from the "Waiting for enrollment" to the Peek
home screen.